# dhuolib

![Version](https://img.shields.io/badge/version-0.1.0-blue.svg?cacheSeconds=2592000)
[![License: MIT](https://img.shields.io/badge/License-MIT-grenn.svg)](#)

> Library for data science on DHuO Data 

### 🏠 [Homepage](https://gitlab.engdb.com.br/dhuo-plat/dhuo-data/data-science/dhuolib)

## Install


`dhuolib` supports Python 3.8 and higher.

### System-wide or user-wide installation with pipx

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `dhuolib`.

```sh
$ pip install dhuolib
```

## Usage

Login at DHuO Platform
```sh
$ dh login
```

Create Project
```sh
$ dh create [project_name]
```

List Projects
```sh
$ dh list 
```

Status of current project
```sh
$ dh status
```

Clone project
```sh
$ dh get [project_id]
```
